
Changelog
=========

0.0.4 (04.02.2022)
---------------------

* no functional changes in this release,
  just in tooling/CI

0.0.3 (04.02.2022)
---------------------

* no functional changes in this release,
  just in tooling/CI

0.0.2 (01.02.2021)
---------------------

* Connected appveyor
* Added automatic pypi upload via travis

0.0.1 (2021-01-29)
------------------

* Modernized setup.py
* Fixed automatic build

0.0.0 (2021-01-28)
------------------

* First release on PyPI.
